Crate explainable_macros

Crate explainable_macros 

Procedural macro support for the explainable crate.

This crate is an implementation detail. Use the re-exported explainable::explainable attribute macro rather than depending on this crate directly.

Attribute Macros

explainable
Annotate an operation trait to generate the full explaining scaffolding for every method in that trait.